@@ -121,8 +121,7 @@ r <- function(func, args = list(), libpath = .libPaths(),
                 c(CRAN = "https://cloud.r-project.org")),
               stdout = NULL, stderr = NULL,
               error = getOption("callr.error", "error"),
-              cmdargs = c("--no-site-file", "--slave",
-                "--no-save", "--no-restore"),
+              cmdargs = c("--slave", "--no-save", "--no-restore"),
               show = FALSE, callback = NULL,
               block_callback = NULL, spinner = show && interactive(),
               system_profile = FALSE, user_profile = FALSE,
